mdsbackuplib
============
Stores QEMU/KVM-instances to a tar-archive, compressed, encrypted,
upload to backupserver


Install
=======
pip install mds-mdsbackuplib

Requires
========
tar, gpg, curl

Changes
=======

*0.5.3 - 21.12.2018*

 - fix: removed unnecessary imports
 - added protocols for upload

*0.5.2 - 20.12.2018*

 - public version
